#ifndef _CUSEFUL_H_
#define _CUSEFUL_H_

/* function: digits
   computes the number characters required to store an integer base 10
   as a string. It will include a character for the negative sign. It
   will not include a character for the string termination symbol.

   This function should be much faster than the usual call to a
   logarithm function.
 */
int digits(int n);

#endif
